/*
 * Transcoder.Native LogFileOpener.cpp
 * Copyright (C) 2007-2008 doubleTwist Corporation
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#include "LogFileOpener.h"

#pragma warning(push)
#pragma warning(disable : 4244)
extern "C"
{
#include "avformat.h"
}
#pragma warning(pop)

static std::string sLogFilePath;
static FILE* sLogFile = 0;

using transcode::LogFileOpener;

void av_log_custom_callback(void* ptr, int level, const char* fmt, va_list vl)
{
    static int print_prefix=1;
    AVClass* avc= ptr ? *(AVClass**)ptr : NULL;
    if(level>av_log_get_level())
        return;
#undef fprintf
    if(print_prefix && avc) {
            fprintf(sLogFile, "[%s @ %p]", avc->item_name(ptr), avc);
    }
#define fprintf please_use_av_log

    print_prefix= strstr(fmt, "\n") != NULL;

    vfprintf(sLogFile, fmt, vl);
}

void LogFileOpener::SetLogFile(const std::string& filePath)
{
	sLogFilePath = filePath;
}

LogFileOpener::LogFileOpener()
{
	// Is a file already open?
	if (sLogFile != 0)
		return;

	if (!sLogFilePath.empty())
		sLogFile = fopen(sLogFilePath.c_str(), "w");

	if (sLogFile != 0)
		av_log_set_callback(av_log_custom_callback);
}

LogFileOpener::~LogFileOpener()
{
	av_log_set_callback(av_log_default_callback);

	if (sLogFile != 0)
	{
		fclose(sLogFile);
		sLogFile = 0;
	}
}