/*
 * Transcoder.Server Program.cs
 * Copyright (C) 2007-2008 doubleTwist Corporation
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

using System;
using System.Collections.Generic;
using System.Diagnostics;
using System.Threading;
using System.Windows.Forms;
using System.Runtime.Remoting;
using System.Reflection;
using System.IO;

using Dune.Components.Transcode;

namespace TranscodeServer
{
	static class Program
	{
		/// <summary>
		/// The main entry point for the application.
		/// </summary>
		[STAThread]
		static void Main()
		{
            try
            {
				Assembly assembly = Assembly.GetAssembly(typeof(Dune.Components.Transcode.RemoteTranscoder));
                string parentFolder = Path.GetDirectoryName(assembly.Location);
                string configPath = Path.Combine(parentFolder, "Transcoder.server.exe.config");

                RemotingConfiguration.Configure(configPath, false);
				MonitorDTApplication();
				Application.Run();
            }
            catch (Exception e)
            {
                MessageBox.Show(e.ToString(), "doubleTwist Transcoder Error");
            }
		}

		static void MonitorDTApplication()
		{
			IDTAppInfo dtAppinfo = (IDTAppInfo)Activator.GetObject(typeof(IDTAppInfo), "ipc://DTApplicationPort/DTAppInfo.rem");
			int processID = dtAppinfo.GetProcessID();

			Thread dtAppMonitor = new Thread(delegate()
				{
					System.Threading.Thread.CurrentThread.Name = "dtAppMonitor";
					using (Process process = Process.GetProcessById(processID))
					{
						process.WaitForExit();
					}
					Application.Exit();
				});
			dtAppMonitor.Start();
		}
	}
}